<?php
# CMS Made Simple Configuration File
# Documentation: https://docs.cmsmadesimple.org/configuration/config-file/config-reference
#
$config['dbms'] = 'mysqli';
$config['db_hostname'] = '[[softdbhost]]';
$config['db_username'] = '[[softdbuser]]';
$config['db_password'] = '[[softdbpass]]';
$config['db_name'] = '[[softdb]]';
$config['db_prefix'] = '[[dbprefix]]';
$config['timezone'] = 'America/New_York';
?>