<?php
/* Database Details */
define('CMTX_DB_DATABASE', '[[softdb]]');
define('CMTX_DB_USERNAME', '[[softdbuser]]');
define('CMTX_DB_PASSWORD', '[[softdbpass]]');
define('CMTX_DB_HOSTNAME', '[[softdbhost]]');
define('CMTX_DB_PORT', '');
define('CMTX_DB_PREFIX', '[[dbprefix]]');
define('CMTX_DB_DRIVER', 'mysqli');
