<?php
$CONFIG = array (
  'instanceid' => '[[instanceid]]',
  'passwordsalt' => '[[passwordsalt]]',
  'secret' => '[[secret]]',
  'trusted_domains' => 
  array (
    0 => '[[domhost]]',
  ),
  'datadirectory' => '[[softdatadir]]',
  'dbtype' => 'mysql',
  'version' => '33.0.2.2',
  'overwrite.cli.url' => '[[softurl]]',
  'dbname' => '[[softdb]]',
  'dbhost' => '[[softdbhost]]',
  'dbtableprefix' => 'oc_',
  'dbuser' => '[[softdbuser]]',
  'dbpassword' => '[[softdbpass]]',
  'installed' => true,
  [[mysql_utf8mb4]]
);
