<?php

return [
    'root'                        => '[[relativeurl]]/',
    'host'                        => '[[softurl]]',
    'upload_root'                 => '[[relativeurl]]/upload/',
    'upload_host'                 => '[[softurl]]/upload',
    'cache_root'                  => '[[relativeurl]]/cache/',
    'is_site_on'                  => 1,
    'off_reason'                  => 'The site is closed for maintenance',
    'sitename'                    => '[[site_name]]',
    'hometitle'                   => 'InstantCMS 2',
    'date_format'                 => 'd.m.Y',
    'date_format_js'              => 'dd.mm.yy',
    'time_zone'                   => 'Europe/London',
    'allow_users_time_zone'       => 1,
    'template'                    => 'modern',
    'template_admin'              => 'admincoreui',
    'template_mobile'             => '',
    'template_tablet'             => '',
    'template_dev'                => '',
    'template_dev_allow_ips'      => '',
    'db_host'                     => '[[softdbhost]]',
    'db_base'                     => '[[softdb]]',
    'db_user'                     => '[[softdbuser]]',
    'db_pass'                     => '[[softdbpass]]',
    'db_prefix'                   => '[[dbprefix]]',
    'db_engine'                   => 'InnoDB',
    'db_charset'                  => 'utf8mb4',
    'clear_sql_mode'              => 1,
    'innodb_full_text'            => 1,
    'db_users_table'              => '[[dbprefix]]users',
    'language'                    => 'en',
    'metakeys'                    => 'site, blog, community',
    'metadesc'                    => '[[site_desc]]',
    'ct_autoload'                 => 'frontpage',
    'ct_default'                  => 'content',
    'frontpage'                   => 'none',
    'debug'                       => 0,
    'emulate_lag'                 => '',
    'cache_enabled'               => 0,
    'cache_method'                => 'files',
    'cache_ttl'                   => 300,
    'cache_host'                  => 'localhost',
    'cache_port'                  => 11211,
    'min_html'                    => 0,
    'merge_css'                   => 0,
    'merge_js'                    => 0,
    'mail_transport'              => 'mail',
    'mail_from'                   => 'noreply@example.com',
    'mail_from_name'              => '',
    'mail_smtp_server'            => 'smtp.example.com',
    'mail_smtp_port'              => 25,
    'mail_smtp_auth'              => 1,
    'mail_smtp_user'              => 'user@example.com',
    'mail_smtp_pass'              => '',
    'is_check_updates'            => 1,
    'detect_ip_key'               => 'REMOTE_ADDR',
    'allow_ips'                   => '',
    'default_editor'              => 3,
    'show_breadcrumbs'            => 1,
    'check_spoofing_type'         => 0,
    'production_time'             => [[timestamp]],
    'native_yaml'                 => 0,
    'session_save_handler'        => 'files',
    'session_name'                => '[[session_name]]',
    'session_save_path'           => '[[softpath]]/tmp',
    'session_maxlifetime'         => 24,
    'controllers_without_widgets' => array (
  0 => 'admin',
),
    'ctype_default'               => array (
),
    'is_404_layout'               => 0
];
