<?php return array (
  'activitylog' => 
  array (
    'enabled' => true,
    'delete_records_older_than_days' => 30,
    'default_log_name' => 'default',
    'default_auth_driver' => NULL,
    'subject_returns_soft_deleted_models' => false,
    'activity_model' => 'App\\ActivityLog',
    'table_name' => 'activity_logs',
  ),
  'app' => 
  array (
    'version' => '1.8.222',
    'name' => 'FreeScout',
    'env' => 'production',
    'debug' => false,
    'url' => '[[softurl]]',
    'timezone' => 'America/New_York',
    'locale' => '[[language]]',
    'locales' => 
    array (
      0 => 'en',
      1 => 'ar',
      2 => 'ca',
      3 => 'zh-CN',
      4 => 'zh-TW',
      5 => 'hr',
      6 => 'cs',
      7 => 'da',
      8 => 'nl',
      9 => 'fi',
      10 => 'fr',
      11 => 'de',
      12 => 'he',
      13 => 'hu',
      14 => 'it',
      15 => 'ja',
      16 => 'kz',
      17 => 'ko',
      18 => 'no',
      19 => 'fa',
      20 => 'pl',
      21 => 'pt-PT',
      22 => 'pt-BR',
      23 => 'ro',
      24 => 'ru',
      25 => 'es',
      26 => 'sk',
      27 => 'sl',
      28 => 'sv',
      29 => 'tr',
      30 => 'uk',
    ),
    'locales_rtl' => 
    array (
      0 => 'ar',
      1 => 'fa',
      2 => 'he',
    ),
    'default_locale' => 'en',
    'real_locale' => '[[language]]',
    'fallback_locale' => 'en',
    'key' => '[[APP_KEY]]',
    'cipher' => 'AES-256-CBC',
    'log' => 'daily',
    'log_level' => 'error',
    'freescout_url' => 'https://freescout.net',
    'freescout_api' => 'https://api.freescout.net/wp-json/',
    'freescout_alt_api' => 'https://cdn.freescout.net/wp-json/',
    'freescout_repo' => 'https://freescout.net/github',
    'freescout_email' => 'support@freescout.net',
    'queue_work_params' => 
    array (
      '--queue' => 'emails,default',
      '--sleep' => '5',
      '--tries' => '1',
      '--timeout' => '1800',
    ),
    'alert_logs' => false,
    'alert_logs_period' => '',
    'fetch_schedule' => 1,
    'fetch_unseen' => 1,
    'colors' => 
    array (
      'main_light' => '#0078d7',
      'main_dark' => '#005a9e',
      'note' => '#ffc646',
      'text_note' => '#e6b216',
      'text_customer' => '#8d959b',
      'text_user' => '#8d959b',
      'bg_user_reply' => '#f4f8fd',
      'bg_note' => '#fffbf1',
    ),
    'options' => 
    array (
      'alert_fetch' => 
      array (
        'default' => false,
      ),
      'alert_fetch_period' => 
      array (
        'default' => 15,
      ),
      'email_branding' => 
      array (
        'default' => true,
      ),
      'open_tracking' => 
      array (
        'default' => true,
      ),
      'subscription_defaults' => 
      array (
        'default' => 
        array (
        ),
      ),
    ),
    'download_attachments_via' => 'php',
    'viewable_attachments' => 
    array (
      0 => 'jpg',
      1 => 'jpeg',
      2 => 'jfif',
      3 => 'pjpeg',
      4 => 'pjp',
      5 => 'apng',
      6 => 'bmp',
      7 => 'gif',
      8 => 'ico',
      9 => 'cur',
      10 => 'png',
      11 => 'tif',
      12 => 'tiff',
      13 => 'webp',
      14 => 'pdf',
      15 => 'txt',
      16 => 'diff',
      17 => 'patch',
      18 => 'json',
      19 => 'mp3',
      20 => 'wav',
      21 => 'ogg',
      22 => 'wma',
    ),
    'viewable_mime_types' => 
    array (
      0 => 'image/.*',
      1 => 'application/pdf',
      2 => 'text/plain',
      3 => 'text/x-diff',
      4 => 'application/json',
      5 => 'audio/.*',
    ),
    'non_viewable_mime_types' => 
    array (
      0 => 'image/svg.*',
    ),
    'customer_allowed_extensions' => 
    array (
      0 => 'jpg',
      1 => 'jpeg',
      2 => 'png',
      3 => 'gif',
      4 => 'bmp',
      5 => 'webp',
      6 => 'mp3',
      7 => 'wav',
      8 => 'ogg',
      9 => 'wma',
      10 => 'pdf',
      11 => 'txt',
      12 => 'csv',
      13 => 'doc',
      14 => 'docx',
      15 => 'xls',
      16 => 'xlsx',
    ),
    'customer_allowed_mime_types' => 
    array (
      0 => 'image/jpg',
      1 => 'image/jpeg',
      2 => 'image/gif',
      3 => 'image/bmp',
      4 => 'image/x-ms-bmp',
      5 => 'image/webp',
      6 => 'audio/mpeg',
      7 => 'audio/wav',
      8 => 'audio/x-wav',
      9 => 'audio/ogg',
      10 => 'audio/x-ms-wma',
      11 => 'application/pdf',
      12 => 'text/plain',
      13 => 'text/csv',
      14 => 'application/msword',
      15 => 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
      16 => 'application/vnd.ms-excel',
      17 => 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
    ),
    'no_retry_mail_errors' => '(no valid recipients|does not comply with RFC|message file too big|malformed address)',
    'email_conv_history' => 'none',
    'max_message_size' => '20',
    'email_user_history' => 'full',
    'user_permissions' => '',
    'use_mail_date_on_fetching' => false,
    'since_without_quotes_on_fetching' => false,
    'fetching_bunch_size' => 100,
    'dashboard_path' => '',
    'login_path' => 'login',
    'home_controller' => 'SecureController@dashboard',
    'disable_updating' => false,
    'custom_number' => false,
    'proxy' => '',
    'custom_mail_headers' => '',
    'curl_timeout' => 40,
    'curl_connect_timeout' => 30,
    'curl_user_agent' => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 7_1_4) AppleWebKit/603.26 (KHTML, like Gecko) Chrome/55.0.3544.220 Safari/534',
    'curl_ssl_verifypeer' => true,
    'customer_photo_size' => 64,
    'user_photo_size' => 50,
    'update_folder_counters_in_background' => false,
    'show_only_assigned_conversations' => '',
    'limit_user_customer_visibility' => false,
    'x_frame_options' => true,
    'csp_script_src' => '',
    'csp_custom' => '',
    'cloudflare_is_used' => false,
    'alternative_reply_separation' => false,
    'remote_host_white_list' => '',
    'trusted_hosts' => '',
    'allowed_user_agents' => '',
    'providers' => 
    array (
      0 => 'Illuminate\\Auth\\AuthServiceProvider',
      1 => 'Illuminate\\Broadcasting\\BroadcastServiceProvider',
      2 => 'Illuminate\\Bus\\BusServiceProvider',
      3 => 'Illuminate\\Cache\\CacheServiceProvider',
      4 => 'Illuminate\\Foundation\\Providers\\ConsoleSupportServiceProvider',
      5 => 'Illuminate\\Cookie\\CookieServiceProvider',
      6 => 'Illuminate\\Database\\DatabaseServiceProvider',
      7 => 'Illuminate\\Encryption\\EncryptionServiceProvider',
      8 => 'Illuminate\\Filesystem\\FilesystemServiceProvider',
      9 => 'Illuminate\\Foundation\\Providers\\FoundationServiceProvider',
      10 => 'Illuminate\\Hashing\\HashServiceProvider',
      11 => 'Illuminate\\Mail\\MailServiceProvider',
      12 => 'Illuminate\\Notifications\\NotificationServiceProvider',
      13 => 'Illuminate\\Pagination\\PaginationServiceProvider',
      14 => 'Illuminate\\Pipeline\\PipelineServiceProvider',
      15 => 'Illuminate\\Queue\\QueueServiceProvider',
      16 => 'Illuminate\\Redis\\RedisServiceProvider',
      17 => 'Illuminate\\Auth\\Passwords\\PasswordResetServiceProvider',
      18 => 'Illuminate\\Session\\SessionServiceProvider',
      19 => 'Illuminate\\Translation\\TranslationServiceProvider',
      20 => 'Illuminate\\Validation\\ValidationServiceProvider',
      21 => 'Illuminate\\View\\ViewServiceProvider',
      22 => 'Devfactory\\Minify\\MinifyServiceProvider',
      23 => 'App\\Providers\\AppServiceProvider',
      24 => 'App\\Providers\\AuthServiceProvider',
      25 => 'App\\Providers\\BroadcastServiceProvider',
      26 => 'App\\Providers\\EventServiceProvider',
      27 => 'App\\Providers\\RouteServiceProvider',
      28 => 'App\\Providers\\PolycastServiceProvider',
      29 => 'Codedge\\Updater\\UpdaterServiceProvider',
    ),
    'aliases' => 
    array (
      'App' => 'Illuminate\\Support\\Facades\\App',
      'Artisan' => 'Illuminate\\Support\\Facades\\Artisan',
      'Auth' => 'Illuminate\\Support\\Facades\\Auth',
      'Blade' => 'Illuminate\\Support\\Facades\\Blade',
      'Broadcast' => 'Illuminate\\Support\\Facades\\Broadcast',
      'Bus' => 'Illuminate\\Support\\Facades\\Bus',
      'Cache' => 'Illuminate\\Support\\Facades\\Cache',
      'Config' => 'Illuminate\\Support\\Facades\\Config',
      'Cookie' => 'Illuminate\\Support\\Facades\\Cookie',
      'Crypt' => 'Illuminate\\Support\\Facades\\Crypt',
      'DB' => 'Illuminate\\Support\\Facades\\DB',
      'Eloquent' => 'Illuminate\\Database\\Eloquent\\Model',
      'Event' => 'Illuminate\\Support\\Facades\\Event',
      'File' => 'Illuminate\\Support\\Facades\\File',
      'Gate' => 'Illuminate\\Support\\Facades\\Gate',
      'Hash' => 'Illuminate\\Support\\Facades\\Hash',
      'Lang' => 'Illuminate\\Support\\Facades\\Lang',
      'Log' => 'Illuminate\\Support\\Facades\\Log',
      'Mail' => 'Illuminate\\Support\\Facades\\Mail',
      'Notification' => 'Illuminate\\Support\\Facades\\Notification',
      'Password' => 'Illuminate\\Support\\Facades\\Password',
      'Queue' => 'Illuminate\\Support\\Facades\\Queue',
      'Redirect' => 'Illuminate\\Support\\Facades\\Redirect',
      'Redis' => 'Illuminate\\Support\\Facades\\Redis',
      'Request' => 'Illuminate\\Support\\Facades\\Request',
      'Response' => 'Illuminate\\Support\\Facades\\Response',
      'Route' => 'Illuminate\\Support\\Facades\\Route',
      'Schema' => 'Illuminate\\Support\\Facades\\Schema',
      'Session' => 'Illuminate\\Support\\Facades\\Session',
      'Storage' => 'Illuminate\\Support\\Facades\\Storage',
      'URL' => 'Illuminate\\Support\\Facades\\URL',
      'Validator' => 'Illuminate\\Support\\Facades\\Validator',
      'View' => 'Illuminate\\Support\\Facades\\View',
      'Minify' => 'Devfactory\\Minify\\Facades\\MinifyFacade',
      'Helper' => 'App\\Misc\\Helper',
      'MailHelper' => 'App\\Misc\\Mail',
      'ModuleHelper' => 'App\\Module',
      'WpApi' => 'App\\Misc\\WpApi',
      'Option' => 'App\\Option',
      'Str' => 'Illuminate\\Support\\Str',
      'Updater' => 'Codedge\\Updater\\UpdaterFacade',
    ),
  ),
  'auth' => 
  array (
    'defaults' => 
    array (
      'guard' => 'web',
      'passwords' => 'users',
    ),
    'guards' => 
    array (
      'web' => 
      array (
        'driver' => 'session',
        'provider' => 'users',
      ),
    ),
    'providers' => 
    array (
      'users' => 
      array (
        'driver' => 'eloquent',
        'model' => 'App\\User',
      ),
    ),
    'passwords' => 
    array (
      'users' => 
      array (
        'provider' => 'users',
        'table' => 'password_resets',
        'expire' => 60,
      ),
    ),
  ),
  'broadcasting' => 
  array (
    'default' => 'polycast',
    'connections' => 
    array (
      'polycast' => 
      array (
        'driver' => 'polycast',
        'delete_old' => 2,
      ),
      'pusher' => 
      array (
        'driver' => 'pusher',
        'key' => NULL,
        'secret' => NULL,
        'app_id' => NULL,
        'options' => 
        array (
          'cluster' => NULL,
          'encrypted' => true,
        ),
      ),
      'redis' => 
      array (
        'driver' => 'redis',
        'connection' => 'default',
      ),
      'log' => 
      array (
        'driver' => 'log',
      ),
      'null' => 
      array (
        'driver' => 'null',
      ),
    ),
  ),
  'cache' => 
  array (
    'default' => 'file',
    'stores' => 
    array (
      'apc' => 
      array (
        'driver' => 'apc',
      ),
      'array' => 
      array (
        'driver' => 'array',
      ),
      'database' => 
      array (
        'driver' => 'database',
        'table' => 'cache',
        'connection' => NULL,
      ),
      'file' => 
      array (
        'driver' => 'file',
        'path' => '[[softpath]]/storage/framework/cache/data',
      ),
      'memcached' => 
      array (
        'driver' => 'memcached',
        'persistent_id' => NULL,
        'sasl' => 
        array (
          0 => NULL,
          1 => NULL,
        ),
        'options' => 
        array (
        ),
        'servers' => 
        array (
          0 => 
          array (
            'host' => '127.0.0.1',
            'port' => 11211,
            'weight' => 100,
          ),
        ),
      ),
      'redis' => 
      array (
        'driver' => 'redis',
        'connection' => 'default',
      ),
    ),
    'prefix' => 'laravel_cache',
  ),
  'database' => 
  array (
    'default' => 'mysql',
    'connections' => 
    array (
      'sqlite' => 
      array (
        'driver' => 'sqlite',
        'database' => '[[softdb]]',
        'prefix' => '',
      ),
      'mysql' => 
      array (
        'driver' => 'mysql',
        'host' => '[[softdbhost]]',
        'port' => '3306',
        'database' => '[[softdb]]',
        'username' => '[[softdbuser]]',
        'password' => '[[softdbpass]]',
        'unix_socket' => '',
        'charset' => 'utf8mb4',
        'collation' => 'utf8mb4_unicode_ci',
        'prefix' => '',
        'strict' => false,
        'engine' => NULL,
        'options' => 
        array (
          1014 => true,
        ),
      ),
      'testing' => 
      array (
        'driver' => 'mysql',
        'host' => '127.0.0.1',
        'database' => 'freescout-test',
        'username' => 'freescout-test',
        'password' => 'freescout-test',
        'charset' => 'utf8mb4',
        'collation' => 'utf8mb4_unicode_ci',
        'prefix' => '',
        'strict' => false,
        'engine' => NULL,
      ),
      'testing_pgsql' => 
      array (
        'driver' => 'pgsql',
        'host' => 'localhost',
        'port' => '5432',
        'database' => 'freescout-test',
        'username' => 'freescout-test',
        'password' => 'freescout-test',
        'charset' => 'utf8',
        'prefix' => '',
        'schema' => 'public',
        'sslmode' => 'prefer',
      ),
      'pgsql' => 
      array (
        'driver' => 'pgsql',
        'host' => '[[softdbhost]]',
        'port' => '3306',
        'database' => '[[softdb]]',
        'username' => '[[softdbuser]]',
        'password' => '[[softdbpass]]',
        'charset' => 'utf8',
        'prefix' => '',
        'schema' => 'public',
        'sslmode' => 'prefer',
        'options' => 
        array (
        ),
      ),
      'sqlsrv' => 
      array (
        'driver' => 'sqlsrv',
        'host' => '[[softdbhost]]',
        'port' => '3306',
        'database' => '[[softdb]]',
        'username' => '[[softdbuser]]',
        'password' => '[[softdbpass]]',
        'charset' => 'utf8',
        'prefix' => '',
      ),
    ),
    'migrations' => 'migrations',
    'redis' => 
    array (
      'client' => 'predis',
      'default' => 
      array (
        'host' => '127.0.0.1',
        'password' => NULL,
        'port' => 6379,
        'database' => 0,
      ),
    ),
  ),
  'filesystems' => 
  array (
    'default' => 'local',
    'cloud' => 's3',
    'disks' => 
    array (
      'local' => 
      array (
        'driver' => 'local',
        'root' => '[[softpath]]/storage/app/public',
        'url' => '[[softurl]]/storage',
        'visibility' => 'public',
      ),
      'public' => 
      array (
        'driver' => 'local',
        'root' => '[[softpath]]/storage/app/public',
        'url' => '[[softurl]]/storage',
        'visibility' => 'public',
      ),
      'private' => 
      array (
        'driver' => 'local',
        'root' => '[[softpath]]/storage/app',
        'url' => '[[softurl]]/storage',
        'visibility' => 'public',
      ),
      's3' => 
      array (
        'driver' => 's3',
        'key' => NULL,
        'secret' => NULL,
        'region' => NULL,
        'bucket' => NULL,
      ),
    ),
  ),
  'imap' => 
  array (
    'default' => 'default',
    'accounts' => 
    array (
      'default' => 
      array (
        'host' => 'localhost',
        'port' => 993,
        'protocol' => 'imap',
        'encryption' => 'ssl',
        'validate_cert' => true,
        'username' => 'root@example.com',
        'password' => '',
      ),
    ),
    'options' => 
    array (
      'delimiter' => '/',
      'fetch' => 1,
      'fetch_body' => true,
      'fetch_attachment' => true,
      'fetch_flags' => true,
      'message_key' => 'id',
      'fetch_order' => 'asc',
      'open' => 
      array (
      ),
    ),
  ),
  'installer' => 
  array (
    'core' => 
    array (
      'minPhpVersion' => '7.1.0',
      'maxPhpVersion' => '8.99.99',
    ),
    'final' => 
    array (
      'key' => false,
      'publish' => false,
    ),
    'requirements' => 
    array (
      'php' => 
      array (
        0 => 'OpenSSL',
        1 => 'PDO',
        2 => 'Mbstring',
        3 => 'Tokenizer',
        4 => 'JSON',
        5 => 'XML',
        6 => 'GD',
        7 => 'fileinfo',
        8 => 'ZIP',
        9 => 'iconv',
        10 => 'cURL',
        11 => 'DOM',
        12 => 'libxml',
      ),
    ),
    'permissions' => 
    array (
      'storage/app/' => '775',
      'storage/framework/' => '775',
      'storage/framework/cache/data/' => '775',
      'storage/logs/' => '775',
      'bootstrap/cache/' => '775',
      'public/css/builds/' => '775',
      'public/js/builds/' => '775',
      'public/modules/' => '775',
      'Modules/' => '775',
    ),
    'environment' => 
    array (
      'form' => 
      array (
        'rules' => 
        array (
          'app_url' => 'required|url',
          'database_connection' => 'required|string|max:1000',
          'database_hostname' => 'required|string|max:1000',
          'database_port' => 'required|numeric',
          'database_name' => 'required|string|max:1000',
          'database_username' => 'required|string|max:1000',
          'database_password' => 'required|string|max:1000',
          'admin_email' => 'required|email',
          'admin_first_name' => 'required|string|max:20',
          'admin_last_name' => 'required|string|max:30',
          'admin_password' => 'required|string',
        ),
      ),
    ),
    'installed' => 
    array (
      'redirectOptions' => 
      array (
        'route' => 
        array (
          'name' => 'dashboard',
          'data' => 
          array (
          ),
        ),
        'abort' => 
        array (
          'type' => '404',
        ),
        'dump' => 
        array (
          'data' => 'Dumping a not found message.',
        ),
      ),
    ),
    'installedAlreadyAction' => 'route',
    'updaterEnabled' => 'false',
  ),
  'laroute' => 
  array (
    'path' => 'public/js',
    'filename' => 'laroute',
    'namespace' => 'laroute',
    'absolute' => true,
    'filter' => 'only',
    'action_namespace' => '',
    'template' => 'resources/assets/js/laroute.js',
    'prefix' => '',
  ),
  'mail' => 
  array (
    'driver' => 'mail',
    'host' => NULL,
    'port' => NULL,
    'from' => 
    array (
      'address' => 'hello@example.com',
      'name' => 'Example',
    ),
    'encryption' => 'tls',
    'username' => NULL,
    'password' => NULL,
    'auth_mode' => '',
    'sendmail' => '/usr/sbin/sendmail -bs',
    'markdown' => 
    array (
      'theme' => 'default',
      'paths' => 
      array (
        0 => '[[softpath]]/resources/views/vendor/mail',
      ),
    ),
    'smtp_timeout' => 25,
  ),
  'minify' => 
  array (
    'config' => 
    array (
      'reverse_sort' => true,
      'ignore_environments' => 
      array (
        0 => 'local',
      ),
      'css_build_path' => '/css/builds/',
      'css_url_path' => '[[softurl]]/css/builds/',
      'js_build_path' => '/js/builds/',
      'js_url_path' => '[[softurl]]/js/builds/',
      'disable_mtime' => false,
      'hash_salt' => '',
      'base_url' => '',
    ),
  ),
  'modules' => 
  array (
    'namespace' => 'Modules',
    'stubs' => 
    array (
      'enabled' => true,
      'path' => '[[softpath]]/overrides/nwidart/laravel-modules/src/Commands/stubs',
      'files' => 
      array (
        'start' => 'start.php',
        'routes' => 'Http/routes.php',
        'views/index' => 'Resources/views/index.blade.php',
        'views/master' => 'Resources/views/layouts/master.blade.php',
        'scaffold/config' => 'Config/config.php',
        'composer' => 'composer.json',
      ),
      'replacements' => 
      array (
        'start' => 
        array (
          0 => 'LOWER_NAME',
          1 => 'ROUTES_LOCATION',
        ),
        'routes' => 
        array (
          0 => 'LOWER_NAME',
          1 => 'STUDLY_NAME',
          2 => 'MODULE_NAMESPACE',
        ),
        'json' => 
        array (
          0 => 'LOWER_NAME',
          1 => 'STUDLY_NAME',
          2 => 'MODULE_NAMESPACE',
        ),
        'views/index' => 
        array (
          0 => 'LOWER_NAME',
        ),
        'views/master' => 
        array (
          0 => 'STUDLY_NAME',
        ),
        'scaffold/config' => 
        array (
          0 => 'STUDLY_NAME',
        ),
        'composer' => 
        array (
          0 => 'LOWER_NAME',
          1 => 'STUDLY_NAME',
          2 => 'VENDOR',
          3 => 'AUTHOR_NAME',
          4 => 'AUTHOR_EMAIL',
          5 => 'MODULE_NAMESPACE',
        ),
      ),
      'gitkeep' => true,
    ),
    'paths' => 
    array (
      'modules' => '[[softpath]]/Modules',
      'assets' => '[[softpath]]/public/modules',
      'migration' => '[[softpath]]/database/migrations',
      'generator' => 
      array (
        'config' => 
        array (
          'path' => 'Config',
          'generate' => true,
        ),
        'command' => 
        array (
          'path' => 'Console',
          'generate' => true,
        ),
        'migration' => 
        array (
          'path' => 'Database/Migrations',
          'generate' => true,
        ),
        'seeder' => 
        array (
          'path' => 'Database/Seeders',
          'generate' => true,
        ),
        'factory' => 
        array (
          'path' => 'Database/factories',
          'generate' => true,
        ),
        'model' => 
        array (
          'path' => 'Entities',
          'generate' => true,
        ),
        'controller' => 
        array (
          'path' => 'Http/Controllers',
          'generate' => true,
        ),
        'filter' => 
        array (
          'path' => 'Http/Middleware',
          'generate' => true,
        ),
        'request' => 
        array (
          'path' => 'Http/Requests',
          'generate' => true,
        ),
        'provider' => 
        array (
          'path' => 'Providers',
          'generate' => true,
        ),
        'assets' => 
        array (
          'path' => 'Resources/assets',
          'generate' => true,
        ),
        'lang' => 
        array (
          'path' => 'Resources/lang',
          'generate' => true,
        ),
        'views' => 
        array (
          'path' => 'Resources/views',
          'generate' => true,
        ),
        'test' => 
        array (
          'path' => 'Tests',
          'generate' => true,
        ),
        'repository' => 
        array (
          'path' => 'Repositories',
          'generate' => false,
        ),
        'event' => 
        array (
          'path' => 'Events',
          'generate' => false,
        ),
        'listener' => 
        array (
          'path' => 'Listeners',
          'generate' => false,
        ),
        'policies' => 
        array (
          'path' => 'Policies',
          'generate' => false,
        ),
        'rules' => 
        array (
          'path' => 'Rules',
          'generate' => false,
        ),
        'jobs' => 
        array (
          'path' => 'Jobs',
          'generate' => false,
        ),
        'emails' => 
        array (
          'path' => 'Emails',
          'generate' => false,
        ),
        'notifications' => 
        array (
          'path' => 'Notifications',
          'generate' => false,
        ),
        'resource' => 
        array (
          'path' => 'Transformers',
          'generate' => false,
        ),
        'public' => 
        array (
          'path' => 'Public',
          'generate' => true,
        ),
      ),
    ),
    'scan' => 
    array (
      'enabled' => false,
      'paths' => 
      array (
        0 => '[[softpath]]/vendor/*/*',
      ),
    ),
    'composer' => 
    array (
      'vendor' => 'freescout',
      'author' => 
      array (
        'name' => 'FreeScout',
        'email' => 'support@freescout.net',
      ),
    ),
    'cache' => 
    array (
      'enabled' => true,
      'key' => 'laravel-modules',
      'lifetime' => 60,
    ),
    'register' => 
    array (
      'translations' => true,
      'files' => 'register',
    ),
  ),
  'purifier' => 
  array (
    'encoding' => 'UTF-8',
    'finalize' => true,
    'cachePath' => '[[softpath]]/storage/app/purifier',
    'cacheFileMode' => 493,
    'settings' => 
    array (
      'default' => 
      array (
        'HTML.Doctype' => 'HTML 4.01 Transitional',
        'HTML.Allowed' => 'div[style],b,strong,i,em,u,a[href|title|style],ul,ol,li,p[style],br,span[style],img[width|height|alt|src|style],table[style|border|bgcolor|cellspacing|cellpadding|border|width|class],tr[style|bgcolor],td[style|colspan|rowspan|width|bgcolor|border|valign|align],th[style|colspan|rowspan],thead,tfoot,tbody,blockquote,pre,s,strike,font[style|color],h1[style],h2[style],h3[style],h4[style],h5[style],h6,center',
        'CSS.AllowedProperties' => 'display,overflow,border-radius,letter-spacing,white-space,font-size,margin,margin-top,margin-right,margin-bottom,margin-left,background,text-transform,max-width,max-height,width,height,font,padding,padding-top,padding-right,padding-bottom,padding-left,font-family,border-color,font-weight,font-style,text-decoration,color,background-color,text-align,border,border-top,border-left,border-bottom,border-right',
        'AutoFormat.AutoParagraph' => true,
        'AutoFormat.RemoveEmpty' => true,
        'CSS.Proprietary' => true,
        'CSS.AllowTricky' => true,
        'CSS.MaxImgLength' => NULL,
        'URI.AllowedSchemes' => 
        array (
          'http' => true,
          'https' => true,
          'mailto' => true,
          'ftp' => true,
          'nntp' => true,
          'news' => true,
          'tel' => true,
          'data' => true,
        ),
      ),
      'test' => 
      array (
        'Attr.EnableID' => 'true',
      ),
      'youtube' => 
      array (
        'HTML.SafeIframe' => 'true',
        'URI.SafeIframeRegexp' => '%^(http://|https://|//)(www.youtube.com/embed/|player.vimeo.com/video/)%',
      ),
      'custom_definition' => 
      array (
        'id' => 'html5-definitions',
        'rev' => 1,
        'debug' => false,
        'elements' => 
        array (
          0 => 
          array (
            0 => 'section',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
          ),
          1 => 
          array (
            0 => 'nav',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
          ),
          2 => 
          array (
            0 => 'article',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
          ),
          3 => 
          array (
            0 => 'aside',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
          ),
          4 => 
          array (
            0 => 'header',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
          ),
          5 => 
          array (
            0 => 'footer',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
          ),
          6 => 
          array (
            0 => 'address',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
          ),
          7 => 
          array (
            0 => 'hgroup',
            1 => 'Block',
            2 => 'Required: h1 | h2 | h3 | h4 | h5 | h6',
            3 => 'Common',
          ),
          8 => 
          array (
            0 => 'figure',
            1 => 'Block',
            2 => 'Optional: (figcaption, Flow) | (Flow, figcaption) | Flow',
            3 => 'Common',
          ),
          9 => 
          array (
            0 => 'figcaption',
            1 => 'Inline',
            2 => 'Flow',
            3 => 'Common',
          ),
          10 => 
          array (
            0 => 'video',
            1 => 'Block',
            2 => 'Optional: (source, Flow) | (Flow, source) | Flow',
            3 => 'Common',
            4 => 
            array (
              'src' => 'URI',
              'type' => 'Text',
              'width' => 'Length',
              'height' => 'Length',
              'poster' => 'URI',
              'preload' => 'Enum#auto,metadata,none',
              'controls' => 'Bool',
            ),
          ),
          11 => 
          array (
            0 => 'source',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
            4 => 
            array (
              'src' => 'URI',
              'type' => 'Text',
            ),
          ),
          12 => 
          array (
            0 => 's',
            1 => 'Inline',
            2 => 'Inline',
            3 => 'Common',
          ),
          13 => 
          array (
            0 => 'var',
            1 => 'Inline',
            2 => 'Inline',
            3 => 'Common',
          ),
          14 => 
          array (
            0 => 'sub',
            1 => 'Inline',
            2 => 'Inline',
            3 => 'Common',
          ),
          15 => 
          array (
            0 => 'sup',
            1 => 'Inline',
            2 => 'Inline',
            3 => 'Common',
          ),
          16 => 
          array (
            0 => 'mark',
            1 => 'Inline',
            2 => 'Inline',
            3 => 'Common',
          ),
          17 => 
          array (
            0 => 'wbr',
            1 => 'Inline',
            2 => 'Empty',
            3 => 'Core',
          ),
          18 => 
          array (
            0 => 'ins',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
            4 => 
            array (
              'cite' => 'URI',
              'datetime' => 'CDATA',
            ),
          ),
          19 => 
          array (
            0 => 'del',
            1 => 'Block',
            2 => 'Flow',
            3 => 'Common',
            4 => 
            array (
              'cite' => 'URI',
              'datetime' => 'CDATA',
            ),
          ),
        ),
        'attributes' => 
        array (
          0 => 
          array (
            0 => 'iframe',
            1 => 'allowfullscreen',
            2 => 'Bool',
          ),
          1 => 
          array (
            0 => 'table',
            1 => 'height',
            2 => 'Text',
          ),
          2 => 
          array (
            0 => 'td',
            1 => 'border',
            2 => 'Text',
          ),
          3 => 
          array (
            0 => 'th',
            1 => 'border',
            2 => 'Text',
          ),
          4 => 
          array (
            0 => 'tr',
            1 => 'width',
            2 => 'Text',
          ),
          5 => 
          array (
            0 => 'tr',
            1 => 'height',
            2 => 'Text',
          ),
          6 => 
          array (
            0 => 'tr',
            1 => 'border',
            2 => 'Text',
          ),
        ),
      ),
      'custom_attributes' => 
      array (
        0 => 
        array (
          0 => 'a',
          1 => 'target',
          2 => 'Enum#_blank,_self,_target,_top',
        ),
      ),
      'custom_elements' => 
      array (
        0 => 
        array (
          0 => 'u',
          1 => 'Inline',
          2 => 'Inline',
          3 => 'Common',
        ),
      ),
    ),
  ),
  'queue' => 
  array (
    'default' => 'database',
    'connections' => 
    array (
      'sync' => 
      array (
        'driver' => 'sync',
      ),
      'database' => 
      array (
        'driver' => 'database',
        'table' => 'jobs',
        'queue' => 'default',
        'retry_after' => 90,
      ),
      'beanstalkd' => 
      array (
        'driver' => 'beanstalkd',
        'host' => 'localhost',
        'queue' => 'default',
        'retry_after' => 90,
      ),
      'sqs' => 
      array (
        'driver' => 'sqs',
        'key' => 'your-public-key',
        'secret' => 'your-secret-key',
        'prefix' => 'https://sqs.us-east-1.amazonaws.com/your-account-id',
        'queue' => 'your-queue-name',
        'region' => 'us-east-1',
      ),
      'redis' => 
      array (
        'driver' => 'redis',
        'connection' => 'default',
        'queue' => 'default',
        'retry_after' => 90,
      ),
    ),
    'failed' => 
    array (
      'database' => 'mysql',
      'table' => 'failed_jobs',
    ),
  ),
  'self-update' => 
  array (
    'default' => 'github',
    'version_installed' => '1.8.222',
    'repository_types' => 
    array (
      'github' => 
      array (
        'type' => 'github',
        'repository_vendor' => 'freescout-helpdesk',
        'repository_name' => 'freescout',
        'repository_url' => '',
        'github_api_url' => 'https://freescout.net/github-api',
        'download_path' => '[[softpath]]/storage/app/updater',
      ),
    ),
    'exclude_folders' => 
    array (
      0 => '.git',
      1 => 'node_modules',
      2 => 'bootstrap/cache',
      3 => 'bower',
      4 => 'storage/app',
      5 => 'storage/framework',
      6 => 'storage/logs',
      7 => 'storage/self-update',
      8 => 'vendor',
    ),
    'log_events' => false,
    'mail_to' => 
    array (
      'address' => '',
      'name' => '',
      'subject_update_available' => 'Update available',
      'subject_update_succeeded' => 'Update succeeded',
    ),
    'artisan_commands' => 
    array (
      'pre_update' => 
      array (
      ),
      'post_update' => 
      array (
        'freescout:after-app-update' => 
        array (
          'class' => 'App\\Console\\Commands\\AfterAppUpdate',
          'params' => 
          array (
          ),
        ),
      ),
    ),
  ),
  'services' => 
  array (
    'mailgun' => 
    array (
      'domain' => NULL,
      'secret' => NULL,
    ),
    'ses' => 
    array (
      'key' => NULL,
      'secret' => NULL,
      'region' => 'us-east-1',
    ),
    'sparkpost' => 
    array (
      'secret' => NULL,
    ),
    'stripe' => 
    array (
      'model' => 'App\\User',
      'key' => NULL,
      'secret' => NULL,
    ),
  ),
  'session' => 
  array (
    'driver' => 'file',
    'lifetime' => 120,
    'expire_on_close' => false,
    'encrypt' => false,
    'files' => '[[softpath]]/storage/framework/sessions',
    'connection' => NULL,
    'table' => 'sessions',
    'store' => NULL,
    'lottery' => 
    array (
      0 => 2,
      1 => 100,
    ),
    'cookie' => 'laravel_session',
    'path' => '/',
    'domain' => NULL,
    'secure' => [[SESSION_SECURE_COOKIE_]],
    'http_only' => true,
    'same_site' => NULL,
  ),
  'subscriptions' => 
  array (
    'defaults' => 
    array (
      1 => 
      array (
        0 => 2,
        1 => 13,
        2 => 3,
        3 => 5,
      ),
      2 => 
      array (
        0 => 2,
        1 => 13,
        2 => 3,
        3 => 5,
      ),
    ),
  ),
  'translation-manager' => 
  array (
    'route' => 
    array (
      'prefix' => '[[relativeurl_]]/translations',
      'middleware' => 
      array (
        0 => 'web',
        1 => 'auth',
        2 => 'roles',
      ),
      'roles' => 
      array (
        0 => 'admin',
      ),
    ),
    'delete_enabled' => true,
    'exclude_groups' => 
    array (
      0 => 'auth',
      1 => 'reminders',
      2 => 'pagination',
      3 => 'passwords',
      4 => 'validation',
      5 => 'installer_messages',
    ),
    'exclude_langs' => 
    array (
    ),
    'sort_keys ' => true,
    'trans_functions' => 
    array (
      0 => 'trans',
      1 => 'trans_choice',
      2 => 'Lang::get',
      3 => 'Lang::choice',
      4 => 'Lang::trans',
      5 => 'Lang::transChoice',
      6 => '@lang',
      7 => '@choice',
      8 => '__',
      9 => '__j',
      10 => '__h',
      11 => '$trans.get',
    ),
    'incorrect_groups' => 
    array (
      0 => 'e',
    ),
  ),
  'trustedproxy' => 
  array (
    'proxies' => 
    array (
      0 => '',
    ),
    'headers' => 
    array (
      1 => 'FORWARDED',
      2 => 'X_FORWARDED_FOR',
      4 => 'X_FORWARDED_HOST',
      8 => 'X_FORWARDED_PROTO',
      16 => 'X_FORWARDED_PORT',
    ),
  ),
  'view' => 
  array (
    'paths' => 
    array (
      0 => '[[softpath]]/resources/views',
    ),
    'compiled' => '[[softpath]]/storage/framework/views',
  ),
  'tinker' => 
  array (
    'dont_alias' => 
    array (
    ),
  ),
);
